@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: zcml.py 103307 2009-08-27 16:34:19Z nadako $
+$Id: zcml.py 127844 2012-09-15 13:01:48Z adamg $
 """
 __docformat__ = "reStructuredText"
 
@@ -56,6 +56,13 @@ class IPageletDirective(zope.component.zcml.IBasicViewInformation):
         required=True
         )
 
+    layer = zope.configuration.fields.GlobalObject(
+        title=u"The request interface or class this pagelet is for.",
+        description=
+        u"Defaults to zope.publisher.interfaces.browser.IDefaultBrowserLayer.",
+        required=False
+        )
+
     for_ = zope.configuration.fields.GlobalObject(
         title=u"Context",
         description=u"The content interface or class this pagelet is for.",
